.. _solvers_modules:

========
Solvers
========

This module documentation contains details about the ``sympy.solvers`` module.
functions.

Contents
========

.. toctree::
    :maxdepth: 2

    diophantine.rst
    inequalities.rst
    ode.rst
    pde.rst
    solvers.rst
    solveset.rst
    